@@ -123,29 +123,13 @@ double WWXClosureEffect::calculateContribution(int alter) const
 
 
 /**
- * Detailed comment in the base class.
+ * The contribution of the tie from the implicit ego to the given alter
+ * to the statistic. It is assumed that preprocessEgo(ego) has been
+ * called before.
  */
-double WWXClosureEffect::statistic(const Network * pSummationTieNetwork) const
+double WWXClosureEffect::tieStatistic(int alter)
 {
-	double statistic = 0;
-	const Network * pNetwork = this->pNetwork();
-	int n = pNetwork->n();
-	double * sums = new double[n];
-
-	for (int i = 0; i < n; i++)
-	{
-		this->calculateSums(i, pNetwork, sums);
-
-		for (IncidentTieIterator iter = pSummationTieNetwork->outTies(i);
-			iter.valid();
-			iter.next())
-		{
-			statistic += sums[iter.actor()];
-		}
-	}
-
-	delete[] sums;
-	return statistic;
+	return this->lsums[alter];
 }
 
 }
