@@ -69,6 +69,9 @@ public:
 	int n() const;
 	virtual int m() const = 0;
 	virtual LongitudinalData * pData() const = 0;
+	int id() const;
+	virtual bool networkVariable() const;
+	virtual bool behaviorVariable() const;
 
 	inline const Function * pEvaluationFunction() const;
 	inline const Function * pEndowmentFunction() const;
@@ -88,6 +91,7 @@ public:
 	void calculateRates();
 	double totalRate() const;
 	double rate(int actor) const;
+	inline double basicRate() const;
 
 	int simulatedDistance() const;
 
@@ -103,24 +107,57 @@ public:
 	double reciprocalDegreeScore(const NetworkVariable * pNetwork) const;
 	double inverseOutDegreeScore(const NetworkVariable * pNetwork) const;
 
+	// Maximum likelihood related
+
 	/**
 	 * Calculates the probability of the given ministep assuming that the
 	 * ego of the ministep will change this variable.
 	 */
 	virtual double probability(MiniStep * pMiniStep) = 0;
 
+	virtual bool validMiniStep(const MiniStep * pMiniStep) const;
+
+	void updateEffectParameters();
+	void updateEffectInfoParameters();
+
+	/**
+	 * Returns if the observed value for the option of the given ministep
+	 * is missing at either end of the period.
+	 */
+	virtual bool missing(const MiniStep * pMiniStep) const = 0;
+
+	/**
+	 * Returns if the given ministep is structurally determined for the period
+	 */
+	virtual bool structural(const MiniStep * pMiniStep) const = 0;
+
+	/**
+	 * Generates a random ministep for the given ego.
+	 */
+	virtual MiniStep * randomMiniStep(int ego) = 0;
+
+	void calculateMaximumLikelihoodRateScores(int activeMiniStepCount);
+	void calculateMaximumLikelihoodRateDerivatives(int activeMiniStepCount);
+	double basicRateDerivative() const;
+	virtual double calculateChoiceProbability(const MiniStep * pMiniStep) const = 0;
+
+	// Bayesian related
+	void sampleBasicRate(int miniStepCount);
+	double sampleParameters(double scaleFactor);
+
 protected:
 	inline EpochSimulation * pSimulation() const;
 	void simulatedDistance(int distance);
+	void invalidateRates();
 
 private:
 	void initializeFunction(Function * pFunction,
 		const vector<EffectInfo *> & rEffects) const;
 
-	virtual double calculateRate(int i);
+	bool constantRates() const;
+	double calculateRate(int i);
 	double structuralRate(int i) const;
 	void updateCovariateRates();
-	inline double basicRate() const;
 
 	// A simulation of the actor-based model, which owns this variable
 	EpochSimulation * lpSimulation;
@@ -172,6 +209,10 @@ private:
 	// The score for the basic rate parameter for this variable for this period
 	double lbasicRateScore;
 
+	// The derivative for the basic rate parameter for this variable for
+	// this period
+	double lbasicRateDerivative;
+
 	// Scores for rate effects depending on constant covariates
 	map<const ConstantCovariate *, double> lconstantCovariateScores;
 
@@ -192,6 +233,18 @@ private:
 
 	// Scores for rate effects depending on inverse degree
 	map<const NetworkVariable *, double> linverseOutDegreeScores;
+
+	// Indicates if the rates are valid and shouldn't be recalculated
+	// provided that the rates are constant during the period.
+
+	int lvalidRates;
+
+	// store for number of acceptances and rejections for non basic rate 
+	// parameters in Bayesian modelling
+
+	int lacceptances;
+	int lrejections;
+
 };
 
 
